@@ -1,6 +1,7 @@
 from flask_restful import Resource
 from flask import request
 from FastCNN.prx.GongDaProxy import predictSingle
+from FastCNN.prx.ValidProxy import predictPSingle2
 from FastCNN.prx.PathProxy import PathProxy
 
 class FastCNNApi(Resource):
@@ -51,6 +52,36 @@ class FastCNNApi(Resource):
         rtn['success'] = True
         return rtn
     
+    def predictPSingle2():
+        rtn = {'success':False}
+        projectid = request.form.get("projectid")
+        if not projectid:
+            rtn["error"] = "projectid is nesserary"
+            return rtn
+        
+        imagepath = request.form.get("imagepath")
+        if not imagepath:
+            rtn["error"] = "imagepath is nesserary"
+            return rtn
+        
+        modeltag = request.form.get("modeltag")
+        if not modeltag:
+            rtn["error"] = "modelid is nesserary"
+            return rtn
+        
+        ckpt = request.form.get("ckpt")
+        if not ckpt:
+            rtn["error"] = "ckpt type is nesserary"
+            return rtn
+        try:
+            data = predictSingle2(projectid,modeltag,imagepath,ckpt)
+        except Exception as err:
+            rtn['data'] = str(err)
+            return rtn
+        rtn['data'] = data
+        rtn['success'] = True
+        return rtn
+    
     def post(self):
         _cmd = request.form.get('cmd')
         
@@ -62,3 +93,6 @@ class FastCNNApi(Resource):
         
         if _cmd == "testPicture":
             return FastCNNApi.testPicture()
+        
+        if _cmd == "predictPSingle2":
+            return FastCNNApi.predictPSingle2()
