@@ -112,6 +112,12 @@ class MACallBack2(Callback):
         self.model.save_weights(modelpath)
         pass
     
+    def saveModelEpoch(modelpath,epoch):
+        f = open(modelpath,'w')
+        f.write(str(epoch))
+        f.close()
+        pass
+    
     def on_epoch_end(self,epoch, logs=None):
         train_loss = logs['loss']
         train_acc = logs['sparse_categorical_accuracy']
@@ -148,15 +154,22 @@ class MACallBack2(Callback):
             trainmodel = PathProxy2.getTrainCKPT(projectname,model_tag)
             validmodel = PathProxy2.getValidCKPT(projectname,model_tag)
             
+            trainmodelpath = PathProxy2.getTrainCKPTPath(projectname,model_tag)
+            validmodelpath = PathProxy2.getValidCKPTPath(projectname,model_tag)
+            
             if train_mean > max_train_acc:
                 #save model here
                 self.saveModel(trainmodel)
                 self.max_train_acc = train_mean
+                
+                MACallBack2.saveModelEpoch(trainmodelpath,epoch)
             
             if valid_mean > max_valid_acc:
                 #save model here
                 self.saveModel(validmodel)
                 self.max_valid_acc = valid_mean
+                
+                MACallBack2.saveModelEpoch(validmodelpath,epoch)
             
             tlog.add(trainlog,(train_loss,train_acc,train_mean,valid_loss,valid_acc,valid_mean))
             
